@@ -34,7 +34,7 @@ logger = logging.getLogger(__name__)
 
 
 COUNTRY_CODE_RE = re.compile(r"^[A-Z]{2}$")
-LOCALE_CODE_RE = re.compile(r"^[a-z]{2}(_[A-Z]{2})?$")
+LOCALE_CODE_RE = re.compile(r"^[a-z]{2,}([_|\-][\da-zA-Z]{2,})*$")
 
 
 class NoAuthenticationError(Exception):
